Class GroupMessage

  • All Implemented Interfaces:
    Message

    public abstract class GroupMessage
    extends Object
    implements Message
    The group API call is how you associate an individual user with a group—be it a company, organization, account, project, team or whatever other crazy name you came up with for the same concept! It also lets you record custom traits about the group, like industry or number of employees. Calling group is a slightly more advanced feature, but it’s helpful if you have accounts with multiple users.

    Use builder(java.lang.String) to construct your own instances.

    See Also:
    Group