Package com.segment.analytics.messages
Interface Message
-
- All Known Implementing Classes:
AliasMessage,GroupMessage,IdentifyMessage,PageMessage,ScreenMessage,TrackMessage
public interface MessageEncapsulates properties common to all messages. Although not enforced by the compiler, either theanonymousId()oruserId()must be provided.For any functions that accept a map, such as
integrations(),context(),TrackMessage.properties(),ScreenMessage.properties(),IdentifyMessage.traits(), orGroupMessage.traits(), we'll make an internal copy of the map provided. If you use Guava, we'll use it'sImmutableMap#copyOfmethods instead.There are a few limitations to be aware of when using Guava — mainly that null keys or values are not permitted and duplicate keys are not permitted. For more details, refer to Guava's Javadocs.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static classMessage.Type
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description StringanonymousId()Map<String,?>context()Map<String,Object>integrations()StringmessageId()DatesentAt()Datetimestamp()Message.Typetype()StringuserId()
-