Package com.segment.analytics.messages
Class PageMessage
- java.lang.Object
-
- com.segment.analytics.messages.PageMessage
-
- All Implemented Interfaces:
Message
public abstract class PageMessage extends Object implements Message
The page call lets you record whenever a user sees a page of your website, along with any properties about the page.Use
builder(java.lang.String)to construct your own instances.- See Also:
- Page
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classPageMessage.BuilderFluent API for creatingPageMessageinstances.-
Nested classes/interfaces inherited from interface com.segment.analytics.messages.Message
Message.Type
-
-
Constructor Summary
Constructors Constructor Description PageMessage()
-
Method Summary
All Methods Static Methods Instance Methods Abstract Methods Concrete Methods Modifier and Type Method Description static PageMessage.Builderbuilder(String name)Start building anPageMessageinstance.abstract Stringcategory()abstract Stringname()abstract Map<String,?>properties()PageMessage.BuildertoBuilder()-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
Methods inherited from interface com.segment.analytics.messages.Message
anonymousId, context, integrations, messageId, sentAt, timestamp, type, userId
-
-
-
-
Method Detail
-
builder
public static PageMessage.Builder builder(String name)
Start building anPageMessageinstance.- Parameters:
name- The name of the page the user is on.- Throws:
IllegalArgumentException- if the page name is null or empty- See Also:
- Page
-
name
public abstract String name()
-
category
@Nullable public abstract String category()
-
toBuilder
public PageMessage.Builder toBuilder()
-
-