Package com.segment.analytics.messages
Class ScreenMessage
- java.lang.Object
-
- com.segment.analytics.messages.ScreenMessage
-
- All Implemented Interfaces:
Message
public abstract class ScreenMessage extends Object implements Message
The screen call lets you record whenever a user sees a screen, along with any properties about the screen.Use
builder(java.lang.String)to construct your own instances.- See Also:
- Screen
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classScreenMessage.BuilderFluent API for creatingScreenMessageinstances.-
Nested classes/interfaces inherited from interface com.segment.analytics.messages.Message
Message.Type
-
-
Constructor Summary
Constructors Constructor Description ScreenMessage()
-
Method Summary
All Methods Static Methods Instance Methods Abstract Methods Concrete Methods Modifier and Type Method Description static ScreenMessage.Builderbuilder(String name)Start building anScreenMessageinstance.abstract Stringname()abstract Map<String,?>properties()ScreenMessage.BuildertoBuilder()-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
Methods inherited from interface com.segment.analytics.messages.Message
anonymousId, context, integrations, messageId, sentAt, timestamp, type, userId
-
-
-
-
Method Detail
-
builder
public static ScreenMessage.Builder builder(String name)
Start building anScreenMessageinstance.- Parameters:
name- The name of the screen the user is on.- Throws:
IllegalArgumentException- if the screen name is null or empty- See Also:
- Name
-
name
public abstract String name()
-
toBuilder
public ScreenMessage.Builder toBuilder()
-
-