Package com.segment.analytics.messages
Class ScreenMessage.Builder
- java.lang.Object
-
- com.segment.analytics.messages.MessageBuilder<ScreenMessage,ScreenMessage.Builder>
-
- com.segment.analytics.messages.ScreenMessage.Builder
-
- Enclosing class:
- ScreenMessage
public static class ScreenMessage.Builder extends MessageBuilder<ScreenMessage,ScreenMessage.Builder>
Fluent API for creatingScreenMessageinstances.
-
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description ScreenMessage.Builderproperties(Map<String,?> properties)Set a map of information that describe the screen.protected ScreenMessagerealBuild(Message.Type type, String messageId, Date sentAt, Date timestamp, Map<String,?> context, String anonymousId, String userId, Map<String,Object> integrations)-
Methods inherited from class com.segment.analytics.messages.MessageBuilder
anonymousId, anonymousId, build, context, enableIntegration, integrationOptions, messageId, messageId, sentAt, timestamp, type, userId
-
-
-
-
Method Detail
-
properties
public ScreenMessage.Builder properties(Map<String,?> properties)
Set a map of information that describe the screen. These can be anything you want.- See Also:
- Properties
-
realBuild
protected ScreenMessage realBuild(Message.Type type, String messageId, Date sentAt, Date timestamp, Map<String,?> context, String anonymousId, String userId, Map<String,Object> integrations)
- Specified by:
realBuildin classMessageBuilder<ScreenMessage,ScreenMessage.Builder>
-
-