Class TrackMessage

  • All Implemented Interfaces:
    Message

    public abstract class TrackMessage
    extends Object
    implements Message
    The track API call is how you record any actions your users perform, along with any properties that describe the action.

    Use builder(java.lang.String) to construct your own instances.

    See Also:
    Track